@@ -4,9 +4,9 @@ import os
 class FSFiler():
     def __init__(self, target_directory: str):
         self.target_directory = target_directory
+        os.makedirs(self.target_directory, exist_ok=True)
 
     def write(self, path: str, text: str):
-        self.create_dirs()
         path = self.target_file(path)
         with open(path, 'w') as md:
             md.write(text)
@@ -15,6 +15,3 @@ class FSFiler():
         path = os.path.join(self.target_directory, file_name)
         return path
 
-    def create_dirs(self):
-        os.makedirs(self.target_directory, exist_ok=True)
-
